import EMDY from "@endeavorance/emdy";
import type { BunFile } from "bun";
import { parseMarkdown } from "./markdown";
import type { CLIOptions } from "./options";
import { loadStylesheet } from "./stylesheet";
import { loadTemplate, renderTemplate } from "./template";

/**
 * Build a file and return the rendered HTML string
 * @param infile - The input file to read from
 * @param outfile - The output file to write to
 * @param options - The CLI options containing template and stylesheet paths
 */
export async function buildFile(
  infile: BunFile,
  options: CLIOptions,
): Promise<string> {
  // Load resources
  const input = await infile.text();
  const template = await loadTemplate(options);
  const stylesheet = await loadStylesheet(options);
  const { content, ...props } = EMDY.parse(input) as Record<string, unknown> & {
    content: string;
  };

  // Render markdown
  const html = await parseMarkdown(content);

  // Prepare data
  const title = options.title ?? props.title ?? "Untitled";
  const templateData = {
    content: html,
    title,
    stylesheet: stylesheet,
    timestamp: new Date().toISOString(),
    datetime: new Date().toLocaleString(),
    ...props,
  };

  // Render template
  return renderTemplate(template, templateData);
}
