import rehypeCallouts from "rehype-callouts";
import rehypeRaw from "rehype-raw";
import rehypeSlug from "rehype-slug";
import rehypeStringify from "rehype-stringify";
import { remarkHeadingId } from "remark-custom-heading-id";
import remarkGfm from "remark-gfm";
import remarkParse from "remark-parse";
import remarkRehype from "remark-rehype";
import { unified } from "unified";

/**
 * Parse the provided markdown into an HTML string
 *
 * @param markdown - The markdown string to parse
 * @returns The parsed HTML string in a promise
 */
export async function parseMarkdown(markdown: string): Promise<string> {
  const file = await unified()

    // Parse markdown
    .use(remarkParse)

    // Support github-flavored markdown
    .use(remarkGfm)

    // Accept custom heading ids: # My heading {#custom-id}
    .use(remarkHeadingId)

    // Pass-thru HTML
    .use(remarkRehype, { allowDangerousHtml: true })

    // Process to html/html
    .use(rehypeRaw)

    // Apply heading IDs to headings without a custom ID
    .use(rehypeSlug)

    // Support callouts/admonitions
    .use(rehypeCallouts)

    // Render to string
    .use(rehypeStringify)
    .process(markdown);

  return String(file);
}
