import Path from "node:path";
import DEFAULT_STYLESHEET from "./defaults/default-style.css" with {
  type: "text",
};
import { readFile } from "./file-util";
import type { CLIOptions } from "./options";

const DEFAULT_STYLESHEET_FILE = "_style.css";

/**
 * Attempt to load a custom stylesheet, falling back to a default
 * @param options - The CLI options containing the stylesheet file path
 * @returns The stylesheet string
 */
export async function loadStylesheet(options: CLIOptions): Promise<string> {
  const preamble = options.includeDefaultStylesheet ? DEFAULT_STYLESHEET : "";

  if (options.stylesheetFilePath) {
    const loadedSheet = await readFile(options.stylesheetFilePath);
    return [preamble, loadedSheet].join("\n");
  }

  const checkStylesheetFile = Bun.file(
    Path.join(options.cwd, DEFAULT_STYLESHEET_FILE),
  );

  if (await checkStylesheetFile.exists()) {
    const loadedSheet = await checkStylesheetFile.text();
    return [preamble, loadedSheet].join("\n");
  }

  return DEFAULT_STYLESHEET;
}
